lib Package
===========

:mod:`lib` Package
------------------

.. automodule:: stoqlib.lib
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`algorithms` Module
------------------------

.. automodule:: stoqlib.lib.algorithms
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`appinfo` Module
---------------------

.. automodule:: stoqlib.lib.appinfo
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`autoreload` Module
------------------------

.. automodule:: stoqlib.lib.autoreload
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`barcode` Module
---------------------

.. automodule:: stoqlib.lib.barcode
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`boleto` Module
--------------------

.. automodule:: stoqlib.lib.boleto
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`colorutils` Module
------------------------

.. automodule:: stoqlib.lib.colorutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`configparser` Module
--------------------------

.. automodule:: stoqlib.lib.configparser
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`console` Module
---------------------

.. automodule:: stoqlib.lib.console
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`cookie` Module
--------------------

.. automodule:: stoqlib.lib.cookie
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`countries` Module
-----------------------

.. automodule:: stoqlib.lib.countries
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`crashreport` Module
-------------------------

.. automodule:: stoqlib.lib.crashreport
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`daemonutils` Module
-------------------------

.. automodule:: stoqlib.lib.daemonutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`dateutils` Module
---------------------------

.. automodule:: stoqlib.lib.dateutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`decorators` Module
------------------------

.. automodule:: stoqlib.lib.decorators
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`defaults` Module
----------------------

.. automodule:: stoqlib.lib.defaults
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`devicemanager` Module
---------------------------

.. automodule:: stoqlib.lib.devicemanager
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`diffutils` Module
-----------------------

.. automodule:: stoqlib.lib.diffutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`distutils` Module
-----------------------

.. automodule:: stoqlib.lib.distutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`environment` Module
-------------------------

.. automodule:: stoqlib.lib.environment
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`event` Module
-------------------

.. automodule:: stoqlib.lib.event
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fileutils` Module
-----------------------

.. automodule:: stoqlib.lib.fileutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`formatters` Module
------------------------

.. automodule:: stoqlib.lib.formatters
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`interfaces` Module
------------------------

.. automodule:: stoqlib.lib.interfaces
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`introspection` Module
---------------------------

.. automodule:: stoqlib.lib.introspection
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`invoice` Module
---------------------

.. automodule:: stoqlib.lib.invoice
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`kiwilibrary` Module
-------------------------

.. automodule:: stoqlib.lib.kiwilibrary
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`latscii` Module
---------------------

.. automodule:: stoqlib.lib.latscii
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`message` Module
---------------------

.. automodule:: stoqlib.lib.message
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`osutils` Module
---------------------

.. automodule:: stoqlib.lib.osutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`parameters` Module
------------------------

.. automodule:: stoqlib.lib.parameters
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`payment` Module
---------------------

.. automodule:: stoqlib.lib.payment
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`permissions` Module
-------------------------

.. automodule:: stoqlib.lib.permissions
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`pgpass` Module
--------------------

.. automodule:: stoqlib.lib.pgpass
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`pdf` Module
-----------------

.. automodule:: stoqlib.lib.pdf
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`pluginmanager` Module
---------------------------

.. automodule:: stoqlib.lib.pluginmanager
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`process` Module
---------------------

.. automodule:: stoqlib.lib.process
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`settings` Module
----------------------

.. automodule:: stoqlib.lib.settings
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sintegra` Module
----------------------

.. automodule:: stoqlib.lib.sintegra
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sintegragenerator` Module
-------------------------------

.. automodule:: stoqlib.lib.sintegragenerator
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`stringutils` Module
-------------------------

.. automodule:: stoqlib.lib.stringutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`template` Module
----------------------

.. automodule:: stoqlib.lib.template
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`threadutils` Module
-------------------------

.. automodule:: stoqlib.lib.threadutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`translation` Module
-------------------------

.. automodule:: stoqlib.lib.translation
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`unittestutils` Module
---------------------------

.. automodule:: stoqlib.lib.unittestutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`uptime` Module
--------------------

.. automodule:: stoqlib.lib.uptime
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`validators` Module
------------------------

.. automodule:: stoqlib.lib.validators
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`webservice` Module
------------------------

.. automodule:: stoqlib.lib.webservice
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ibpt` Module
------------------

.. automodule:: stoqlib.lib.ibpt
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    stoqlib.lib.test

